#
# spec file for package niri
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           niri
Version:        0.1.5
Release:        1.1
Summary:        Scrollable-tiling Wayland compositor
License:        GPL-3.0-or-later
URL:            https://github.com/YaLTeR/niri
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{url}/releases/download/v%{version}/niri-%{version}-vendored-dependencies.tar.xz
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  clang
BuildRequires:  pango-devel
BuildRequires:  pipewire-devel
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.70.0
BuildRequires:  wayland-devel
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(cairo-gobject)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(libseat)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(xkbcommon)
# Portal implementations used by niri
Recommends:     xdg-desktop-portal-gtk
Recommends:     xdg-desktop-portal-gnome
Recommends:     gnome-keyring
Recommends:     polkit-gnome
# Recommended utilities, bound in the default config
Recommends:     alacritty
Recommends:     fuzzel
Recommends:     swaylock
# Recommended utilities
Recommends:     swaybg
Recommends:     mako
Recommends:     xwayland-run

%description
A scrollable-tiling Wayland compositor.

Windows are arranged in columns on an infinite strip going to the right.
Opening a new window never causes existing windows to resize.

%prep
%autosetup -a1 -p1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
install -Dm755 -t %{buildroot}%{_bindir} target/release/%{name} 
install -Dm755 -t %{buildroot}%{_bindir} resources/niri-session
install -Dm644 -t %{buildroot}%{_datadir}/wayland-sessions resources/niri.desktop
install -Dm644 -t %{buildroot}%{_datadir}/xdg-desktop-portal resources/niri-portals.conf
install -Dm644 -t %{buildroot}%{_userunitdir} resources/niri{.service,-shutdown.target}

%check

%files
%license LICENSE
%doc README.md resources/default-config.kdl wiki
%{_bindir}/niri
%{_bindir}/niri-session
%dir %{_datadir}/wayland-sessions
%{_datadir}/wayland-sessions/niri.desktop
%dir %{_datadir}/xdg-desktop-portal
%{_datadir}/xdg-desktop-portal/niri-portals.conf
%{_userunitdir}/niri.service
%{_userunitdir}/niri-shutdown.target

%changelog
* Sat Apr 20 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.1.5
  * A big focus in this release was on animations. I've animated
    many more actions: window movement, resizing, and closing.
  * Spring animations are now more robust: values and durations are
    clamped more aggressively where it makes sense.
  * Niri now has basic variable refresh rate (VRR) support.
  * IPC improvements
  * Added an allow-when-locked=true flag for spawn key bindings
    that makes them work when the session is locked.
  * Previous view position is now restored upon unfullscreening a
    window.
  * The SIGPIPE handler is now set to default in niri msg to
    prevent panic backtraces from showing up when stdout is closed.
  * The mouse cursor is now hidden upon touchscreen interaction.
  * Corrected some DRM leasing behavior to fix crashes when DRM
    leasing is unavailable and better handle hotplugging.
  * Added an ease-out-quad easing curve.
  * Fixed warp-mouse-to-focus not triggering when a window is
    closed by unmapping its buffer.
  * Fixed the horizontal touchpad gesture redrawing continuously
    rather than only on touchpad events.
  * Fixed overdamped spring instability being able to crash the
    compositor.
  * Added a microphone mute example bind to the default config.
* Sun Jan 28 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
